#
# spec file for package python-PyICU
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global modname PyICU

Name:           python-%{modname}
Version:        1.9.7
Release:        1.1
Summary:        Python Extension Wrapping the ICU C++ API
License:        MIT
Group:          Development/Libraries/Python
Url:            http://pyicu.osafoundation.org/
Source0:        https://pypi.io/packages/source/P/%{modname}/%{modname}-%{version}.tar.gz
Patch0:         python-%{modname}-%{version}-quote_Version.patch
%{?python_provide:%python_provide python-%{modname}}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  gcc-c++
Provides:       %{modname} = %{version}
Provides:       python-ICU = %{version}
Obsoletes:      python-ICU < 1.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1320
BuildRequires:  %{python_module pytest}
%endif
%if 0%{?suse_version} >= 1210
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
%else
BuildRequires:  libicu-devel
Requires:       python = %{py_ver}
%endif

%python_subpackages

%description
Python extension wrapping IBM's International Components for Unicode C++
library (ICU).

%prep
%setup -q -n %{modname}-%{version}
%patch0

%build
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%fdupes %{buildroot}%{_prefix}

%if 0%{?suse_version} > 1320
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%if 0%{?suse_version} >= 1310
%doc CHANGES CREDITS LICENSE README.md
%else
%doc CHANGES CREDITS LICENSE README
%endif
%{python_sitearch}/*

%changelog
* Thu Jun  8 2017 okurz@suse.com
- Update to 1.9.7
  * Remove dependency on deprecated and removed ICU LayoutEngine
* Tue May 12 2015 lazy.kent@opensuse.org
- Update to 1.9.2 (excluding openSUSE 11.4).
  * Added MANIFEST.in to ensure nothing's missing in the 'sdist'
    package.
  * Enabled -Wwrite-strings and fixed warnings.
  * Added missing conditionals around uses of features in newer ICU
    versions.
- Changes in 1.9.
  * Fixed utf-8 conversion error position reporting.
  * Fixed delete/delete[] bug in common.cpp.
  * Added support for ICU 54.1 and ICU 55.1.
  * Replaced UnicodeString idna methods with new uidna.h UTS #46
    wrapper (55.1).
  * Added wrapper for Char functions and related enums (from
  * uchar.h).
  * Added wrapper for Shape defines and shapeArabic() (from
    ushape.h).
  * Added wrapper for RelativeDateTimeFormatter.
- Drop the source and the patch for openSUSE 12.3.
* Sat Aug  2 2014 lazy.kent@opensuse.org
- Update to 1.8 (excluding openSUSE 11.4 and 12.3).
  * Added wrapper for Locale::getRoot().
  * Added tp_hash implemention for Locale type based on
    Locale::hashCode().
  * Fixed bug 13112.
  * Added support for building with PyPy.
  * Added Locale(lcid) constructor calling uloc_getLocaleForLCID().
  * Added wrapper for CompactDecimalFormat and its createInstance()
    method.
- Changes in 1.7.
  * Added missing #include for <unicode/uscript.h>.
  * Fixed issues building against ICU 4.2.
  * Added wrapper for Script.isRightToLeft().
  * Added support for ICU 53.1.
  * Added wrappers for other Script functions introduced in ICU 51.
- Changes in 1.6.
  * Removed wrappers for some layoutengine.cpp internal flags.
  * Added wrappers for ULocaleData functions.
  * Added wrappers for uscript functions and UScriptCode enum.
  * Added support for ICU 52.1.
  * Added wrapper for Locale::setKeywordValue().
  * Added Locale::removeKeywordValue().
  * Added support for ListFormatter.
- Change BuildRequires: python-distribute -> python-setuptools.
* Fri Mar 15 2013 lazy.kent@opensuse.org
- Update to 1.5 (excluding openSUSE 11.4 and 12.1).
  * Added wrapper for MessageFormat::format(argumentNames,
    arguments, ...).
  * Fixed bug in t_transliterator_filteredTransliterate passing
    UBool for int.
  * Added wrapper for DateFormat::format(Calendar).
  * Added wrapper for Calendar::set(UCalendarDateFields field,
    value).
  * Added wrappers for UnicodeString::toTitle() w/o iterator.
  * Added support for ICU 50.1.
  * Improved test_Collator's testGetSortKey().
  * Added pypi classifiers to PyICU project info.
- Use pkgconfig(*) as build dependencies.
- Don't use "--record-rpm" during install; add to %%files section.
* Wed Jul 18 2012 lazy.kent@opensuse.org
- Fix suse_version for Factory (12.3).
* Wed Apr 18 2012 lazy.kent@opensuse.org
- Update to 1.4.
  * Added support for ICU 49.1.1.
  * Added ScriptCode constants new in 49.0.
  * Implemented wrapper for new NumberFormat.parseCurrency().
  * Added wrapper for Transliterator::toRules().
  * Added missing wrapper for
    RuleBasedNumberFormat(URBNFRuleSetTag, Locale).
  * Fixed bugs.
- Changes in 1.3.
  * Added support for ICU 4.8.1.1.
  * PyICU ready for Python 3.2.
  * Added support for LEFontInstance and LayoutEngine.
  * Fixed bugs.
- Refresh "quote_Version" patch.
- Run tests.
- Patch to fix running tests in openSUSE 11.4.
* Wed Nov  9 2011 lazy.kent@opensuse.org
- Build reqiures python-setuptools or python-distribute (for
  openSUSE >= 12.1).
- spec clean up.
* Wed Sep 21 2011 lazy.kent@opensuse.org
- Update to 1.2.
  * Fixed bugs.
- Dropped "linux3" patch (no need any more).
- Removed obsolete "clean" section and Authors from spec.
* Sat Jul 23 2011 lazy.kent@opensuse.org
- Patch to fix compilation on linux3 platform.
- Use python-setuptools.
- Added LICENSE to docs.
* Mon May 30 2011 lazy.kent@opensuse.org
- Renamed to python-PyICU.
* Sat May 28 2011 lazy.kent@opensuse.org
- Update to 1.1.
- Dropped undefine_DATE patch.
- Refresh quote_Version patch.
- Provides PyICU.
* Thu Feb 17 2011 pth@suse.de
- pyconfig.h defines DATE which breaks ICU's calendar.h
- Fix quoting of PYICU_VER.
* Sun Oct 17 2010 lazy.kent.suse@gmail.com
- Update to 1.0.1.
* Sat Sep 25 2010 lazy.kent.suse@gmail.com
- Update to 1.0.
* Tue Apr  6 2010 lazy.kent.suse@gmail.com
- Initial package created.
